legalnotice

# XMLRésuméLibrary: User Guide

lastModified | Element Reference | level

## Name

legalnotice — A legal statement

## Synopsis

### Content Model

    (para+)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `legalnotice` element contains text that is intended to specify the legal use of a résumé.

### Parents

`legalnotice` may be contained in these elements: `copyright`

## Examples

For examples, see `copyright`

lastModified | Element Reference | level